﻿'
'* Farseer Physics Engine:
'* Copyright (c) 2012 Ian Qvist
'


Imports Microsoft.Xna.Framework


''' <summary>
''' Convert units between display and simulation units.
''' </summary>
Public NotInheritable Class ConvertUnits
    Private Sub New()
    End Sub
    Private Shared _displayUnitsToSimUnitsRatio As Single = 100.0F
    Private Shared _simUnitsToDisplayUnitsRatio As Single = 1 / _displayUnitsToSimUnitsRatio

    Public Shared Sub SetDisplayUnitToSimUnitRatio(displayUnitsPerSimUnit As Single)
        _displayUnitsToSimUnitsRatio = displayUnitsPerSimUnit
        _simUnitsToDisplayUnitsRatio = 1 / displayUnitsPerSimUnit
    End Sub

    Public Shared Function ToDisplayUnits(simUnits As Single) As Single
        Return simUnits * _displayUnitsToSimUnitsRatio
    End Function

    Public Shared Function ToDisplayUnits(simUnits As Integer) As Single
        Return simUnits * _displayUnitsToSimUnitsRatio
    End Function

    Public Shared Function ToDisplayUnits(simUnits As Vector2) As Vector2
        Return simUnits * _displayUnitsToSimUnitsRatio
    End Function

    Public Shared Sub ToDisplayUnits(ByRef simUnits As Vector2, ByRef displayUnits As Vector2)
        Vector2.Multiply(simUnits, _displayUnitsToSimUnitsRatio, displayUnits)
    End Sub

    Public Shared Function ToDisplayUnits(simUnits As Vector3) As Vector3
        Return simUnits * _displayUnitsToSimUnitsRatio
    End Function

    Public Shared Function ToDisplayUnits(x As Single, y As Single) As Vector2
        Return New Vector2(x, y) * _displayUnitsToSimUnitsRatio
    End Function

    Public Shared Sub ToDisplayUnits(x As Single, y As Single, ByRef displayUnits As Vector2)
        displayUnits = Vector2.Zero
        displayUnits.X = x * _displayUnitsToSimUnitsRatio
        displayUnits.Y = y * _displayUnitsToSimUnitsRatio
    End Sub

    Public Shared Function ToSimUnits(displayUnits As Single) As Single
        Return displayUnits * _simUnitsToDisplayUnitsRatio
    End Function

    Public Shared Function ToSimUnits(displayUnits As Double) As Single
        Return CSng(displayUnits) * _simUnitsToDisplayUnitsRatio
    End Function

    Public Shared Function ToSimUnits(displayUnits As Integer) As Single
        Return displayUnits * _simUnitsToDisplayUnitsRatio
    End Function

    Public Shared Function ToSimUnits(displayUnits As Vector2) As Vector2
        Return displayUnits * _simUnitsToDisplayUnitsRatio
    End Function

    Public Shared Function ToSimUnits(displayUnits As Vector3) As Vector3
        Return displayUnits * _simUnitsToDisplayUnitsRatio
    End Function

    Public Shared Sub ToSimUnits(ByRef displayUnits As Vector2, ByRef simUnits As Vector2)
        Vector2.Multiply(displayUnits, _simUnitsToDisplayUnitsRatio, simUnits)
    End Sub

    Public Shared Function ToSimUnits(x As Single, y As Single) As Vector2
        Return New Vector2(x, y) * _simUnitsToDisplayUnitsRatio
    End Function

    Public Shared Function ToSimUnits(x As Double, y As Double) As Vector2
        Return New Vector2(CSng(x), CSng(y)) * _simUnitsToDisplayUnitsRatio
    End Function

    Public Shared Sub ToSimUnits(x As Single, y As Single, ByRef simUnits As Vector2)
        simUnits = Vector2.Zero
        simUnits.X = x * _simUnitsToDisplayUnitsRatio
        simUnits.Y = y * _simUnitsToDisplayUnitsRatio
    End Sub
End Class

